@@ -5,7 +5,7 @@ from pykkn.storage import Storage
 
 
 class Model(Storage):
-    """This object is used to represent the model for data processing in the experiment
+    """This object is used to represent the model for data processing
 
     Parameters
     ----------
@@ -47,4 +47,4 @@ class Model(Storage):
             if isinstance(item, Parameter):
                 self.parameters.append(item)
             else:
-                raise TypeError("the element in list must be a Parameter object")
+                raise TypeError("the element in list must be Parameter object")
